#
# spec file for package wavemon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wavemon
Version:        0.9.6
Release:        1.5
Summary:        An ncurses monitoring application for wireless network devices
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/uoaerg/wavemon
Source:         https://github.com/uoaerg/wavemon/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  libpcap-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libnl-3.0) >= 3.2
BuildRequires:  pkgconfig(libnl-genl-3.0)
BuildRequires:  pkgconfig(ncursesw)

%description
wavemon is a wireless device monitoring application that allows you to
watch signal and noise levels, packet statistics, device configuration
and network parameters of your wireless network hardware. It has
currently only been tested with the Lucent Orinoco series of cards,
although it *should* work (though with varying features) with all
devices supported by the wireless kernel extensions by Jean Tourrilhes.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} `pkg-config --cflags libnl-3.0` -DNCURSES_WIDECHAR -pthread"

%configure \
  --docdir=%{_docdir}/%{name}
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/%{name} %{buildroot}%{_docdir}/

%files
%license LICENSE
%doc README.md
%{_bindir}/wavemon
%{_mandir}/man1/wavemon.1%{?ext_man}
%{_mandir}/man5/wavemonrc.5%{?ext_man}
%{_docdir}/%{name}

%changelog
* Sat Jul 13 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.6
  Enhancements and Fixes
  * Info Screen:
    + Fix hanging receive by switching to non-blocking netlink
    socket.
  Miscellaneous
  * Bump autoconf minimum version to 2.7.1.
* Wed Nov  1 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.5
  Enhancements and Fixes:
  * Info Screen:
    + improve format of percentages (use fixed format rather than
    auto-format).
  Configuration:
    + fix ncurses support for white backgrounds.
    + configuration file now either in
    $XDG_CONFIG_HOME/wavemon/wavemonrc or in
    $HOME/.config/wavemon/wavemonrc
  Miscellaneous
  * avoid including include linux/if.h
  * check and set support for C99 standard
  * configuration file can now be located in XDG_CONFIG_HOME
  * added portable implementation of asprintf(3),
  * updated copied nl80211 header file,
  * make -Wpedantic the default when building.
* Sun Dec 25 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.4
  Enhancements and Fixes:
  * Info Screen
    + fix mis-spelled format identifier
    + add fields for carrier / link mode,
    + handle (accidentally) positive signal levels
    + fix display of bonded interfaces
    + add more network information
    + add IPv6 support
    + use error-checking mutexes
    + display MCS bitrate information
  * Scan Screen
    + do not enable scan if rfkill is enabled
    + unblock data mutex at end (fixing a deadlock condition)
    + reset filter when there are no results
  * History Screen
    + deprecate threshold actions (were not of much use)
    + remove support for noise levels
    + add missing #include
    + add wide-character support
    + reset data when switching between interfaces
  * Menu Bar
    + improve highlighting of selected entries
  Miscellaneous:
  * drop dependency on wireless extensions
  * build uses correct ncurses flags
  * build now uses -Wextra by default
  * build now honours configure CFLAGS
  * update README
  * document how to use wavemon within screen
  * list of wireless interfaces is now also populated via
    nl80211 (no longer ioctl)
* Sat Dec 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.3
  Fixes General
  * proper rendering on UTF-8 terminals (#70),
  * enabled by using libncursesw in place of libncurses,
  * and using wide-characters for rendering where supported.
  Fixes Info Screen:
  * properly clear area when updating with new data,
  * do not leave rx / tx empty when no data available (use 'n/a'
    instead),
  * improve rendering on some terminal types (e.g. ansi),
  * refresh immediately after a window-size change;
  Fixes History Screen:
  * do not display noise / SNR levels when such data is not
    reported by the driver;
  Fixes Scan Screen:
  * fix segmentation fault when no CAP_NET_ADMIN permissions
  * fix locking bug (#78), redoing the original and incorrect fix;
  * as a result, screen now retains data when switching windows;
  Fixes Conf Screen:
  * fix memory leak identified in #73,
  * reorganize into sections via separators.
  Miscellaneous
  * Keyboard shortcuts: can now use 0..9 in place of F10, F1..F9;
  * Scan screen: increased the usable window size by 1 line;
  * Build: updated several outdated build/bootstrap files.
* Sat Oct 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to versino 0.9.2
  General
  * proper rendering on UTF-8 terminals (#70),
  * enabled by using libncursesw in place of libncurses,
  * and using wide-characters for rendering where supported.
  Info Screen:
  * properly clear area when updating with new data,
  * do not leave rx / tx empty when no data available (use 'n/a'
    instead),
  * improve rendering on some terminal types (e.g. ansi),
  * refresh immediately after a window-size change;
  History Screen:
  * do not display noise / SNR levels when such data is not
    reported by the driver;
  Scan Screen:
  * fix segmentation fault when no CAP_NET_ADMIN permissions,
  * fix locking bug (#78), redoing the original and incorrect fix
    (#42),
    as a result, screen now retains data when switching windows;
  Conf Screen:
  * fix memory leak identified in #73,
  * reorganize into sections via separators.
  Miscellaneous
  * Keyboard shortcuts: can now use 0..9 in place of F10,
    F1..F9 (#76);
  * Scan screen: increased the usable window size by 1 line;
  * Build: updated several outdated build/bootstrap files.
* Mon Mar 16 2020 Martin Pluskal <mpluskal@suse.com>
- Clean up spec file with spec-cleaner
* Mon Dec 30 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.1
  Fixes
  * Compatibility:
  - replace non-portable on_exit with portable at_exit
  - address gcc8 compiler warnings;
  * Scan Screen:
  - fix memory leak in scan handler
  * Info Screen:
  - fix logic around uninitialized variable
  * Configuration Screen:
  - fix numerical key issue on ARM 32bit (Raspberri Pi 2)
* Sat May 18 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.0
  General
  * wavemon now has a transparent background.
  Fixes
  * Info Screen:
  - disable locale to avoid funny thousand separators
  - prefer station signal over average station signal
  * Scan Screen:
  - fix bug in displaying TLV elements
  - restore interface state on exit
  Miscellaneous
  * more fixes for reproducible builds - time/date display is gone
  * various code updates (new nl80211.h) and clean-ups.
* Sun Feb 18 2018 mardnh@gmx.de
- Remove patch:
  * reproducible.patch (fixed upstream)
- Update to version 0.8.2
  * Fixes
  - Info Screen:
    + do not warn about missing data if driver returns 0
    signal value (#44),
    + present retry/drop rate also as percentage (#38),
    + remove outdated WEP encryption key information (#8);
  - Scan Screen:
    + revise and improve access to thread data (#42).
  * Miscellaneous
  - build process now sorts input files for reproducible builds
  - miscellaneous fixes, such as typos, email information
  - code clean-up
* Tue May 23 2017 bwiedemann@suse.com
- Override BUILD_DATE for reproducible builds
- Add reproducible.patch to avoid random link order
* Mon May  8 2017 mpluskal@suse.com
- Use pkgconfig style dependencies
* Mon May  8 2017 mardnh@gmx.de
- Update to version 0.8.1
  * fix for  musl  build thanks to @joerg-krause
  * resolved #19, #22, #23, #28
  * info screen: replace interval timer with  pthread
  * fixed an illegal  free  (found on ARM), which seems to also have caused a memory leak on ARM.
- Update to version 0.8.0
  * majority of WEXT functions now replaced by nl80211
  * scan screen has more information (channel utilisation)
    and sorting mode (MAC addresses)
  * info screen contains more output, tested new support
  * for displaying noise floor data (based on nl80211)
  * random signal generator option was dropped
* Wed Apr  8 2015 p.drouand@gmail.com
- Update to version 0.7.6
  * complete redesign based on pthreads to fix terminal bug, as a result of better
    design the scan window now also can be suspended (details of fix are below),
  * add message for 'too much data' (E2BIG) error case,
  * use same formatting (3 digits) for 2/5 GHz,
  * support for changing sort order via keyboard shortcuts (see manpage, several
    ascending/descending sort orders are now available directly on the screen),
  * currently active sort order is now displayed on status line at the bottom,
  * stabilized by-channel sort to always use the same order for identical channels,
  * added 'sort by Essid' to selection of sort menus;
  * add percentage for easier reading of link quality,
  * deprecate use of locale settings for 'discard' information (fixes display);
  * add support for Page Up/Down, Home, and End buttons to ease navigation,
  * added more information to '-v' version information (ncurses/WE versions);
  * fix bug in ranking top/bottom 3 channels in scan window,
  * complete redesign of scan process based on pthreads to fix bug that became
  visible on ncurses >= 5.9.20130504 (slackware 14.1 and debian jessie), caused
  by child/parent both updating the same screen (bug had been hidden by the
  internal buffering of ncurses which was then removed),
- For changes from previous versions, please read the NEWS file
- Update download and project Urls
- Remove autoconf require; not needed anymore
- Remove wavemon-optflags.diff; cflags are passed by configure script
- Remove obsolete %%clean and AUTHORS section
- Enable parallel building with %%{?_smp_mflags}
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Mon Apr 12 2010 davejplater@gmail.com
- Update to version 0.6.10 Removed all patches except wavemon-optflags.diff.
-  *Bug Fixes:
  fixed installation bug which caused manpages to be installed in /man;
  fixed mode of installation to support sandbox-builds on Gentoo (Lovelace);
  improved (automated) linking process, now possible to pass LDFLAGS (Boeck);
  bail out when no statistics are available, instead of flagging an error.
- See /usr/share/doc/packages/wavemon/NEWS for all changes since version 0.4b.
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Fri Jan  2 2009 lmuelle@suse.de
- Handle dBm values in /proc/net/wireless as displayed when IW_QUAL_DBM is set
  by the driver; (bdo#426300); (bnc#463032).
* Wed Oct  8 2008 lmuelle@suse.de
- Fix ordered comparison of pointer with integer zero; (bnc#433389).
* Thu Apr  5 2007 ssommer@suse.de
- added ncurses-devel to BuildRequires
- fixed includes for newer kernel headers
* Sat Nov 11 2006 aj@suse.de
- Fix permissions on man pages.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 31 2005 dmueller@suse.de
- don't build as root
* Sun Feb  6 2005 meissner@suse.de
- truly use rpm_opt_flags, fixed warnings and gcc4 compile problems.
* Thu Apr 17 2003 lmuelle@suse.de
- inital SuSE RPM
